@@ -20,6 +20,23 @@ class Request(Base):
     completed_date = sa.Column('completed_date', sa.Date, nullable=False)
     review_url = sa.Column('review_url', sa.Text(), nullable=False)
 
+    def to_dict(self):
+        return {
+            'domain_name': str(self.domain_name),
+            'url': self.url,
+            'effective_url': self.effective_url,
+            'status_code': self.status_code,
+            'response_time': self.response_time,
+            'completed_date': self.completed_date,
+            'review_url': self.review_url
+        }
+
+    def __str__(self):
+        return "%s (%s)" % (self.url, self.status_code)
+
+    def __repr__(self):
+        return str(self)
+
     @classmethod
     def get_status_code_info(self, domain_name, db):
         result = []
@@ -62,3 +79,16 @@ class Request(Base):
             .filter(Request.domain_name == domain_name) \
             .filter(Request.status_code == status_code) \
             .scalar()
+
+    @classmethod
+    def get_requests_count(cls, db):
+        return int(db.query(sa.func.count(Request.id)).scalar())
+
+    @classmethod
+    def get_last_requests(self, db, current_page=1, page_size=10):
+        lower_bound = (current_page - 1) * page_size
+        upper_bound = lower_bound + page_size
+
+        return db \
+            .query(Request) \
+            .order_by('id desc')[lower_bound:upper_bound]
